@@ -2,10 +2,12 @@
 """Contains helpers for template."""
 
 import uuid
+from math import sqrt
 from typing import Dict, List, Tuple, Union
 
 import pdfrw
 
+from ..middleware.element import Element as ElementMiddleware
 from ..middleware.element import ElementType
 from .constants import Merge as MergeConstants
 from .constants import Template as TemplateCoreConstants
@@ -22,10 +24,11 @@ class Template:
 
         pdf = pdfrw.PdfReader(fdata=pdf)
 
-        for i in range(len(pdf.pages)):
-            elements = pdf.pages[i][TemplateCoreConstants().annotation_key]
-            for j in reversed(range(len(elements))):
-                elements.pop(j)
+        for page in pdf.pages:
+            elements = page[TemplateCoreConstants().annotation_key]
+            if elements:
+                for j in reversed(range(len(elements))):
+                    elements.pop(j)
 
         return Utils().generate_stream(pdf)
 
@@ -40,8 +43,8 @@ class Template:
 
         result = []
 
-        for i in range(len(pdf.pages)):
-            elements = pdf.pages[i][TemplateCoreConstants().annotation_key]
+        for page in pdf.pages:
+            elements = page[TemplateCoreConstants().annotation_key]
             if elements:
                 for element in elements:
                     if not sejda:
@@ -78,10 +81,10 @@ class Template:
 
         result = {}
 
-        for i in range(len(pdf.pages)):
-            elements = pdf.pages[i][TemplateCoreConstants().annotation_key]
+        for i, page in enumerate(pdf.pages):
+            elements = page[TemplateCoreConstants().annotation_key]
+            result[i + 1] = []
             if elements:
-                result[i + 1] = []
                 for element in elements:
                     if not sejda:
                         if (
@@ -116,10 +119,10 @@ class Template:
 
         result = {}
 
-        for i in range(len(pdf.pages)):
-            elements = pdf.pages[i][TemplateCoreConstants().annotation_key]
+        for i, page in enumerate(pdf.pages):
+            elements = page[TemplateCoreConstants().annotation_key]
+            result[i + 1] = []
             if elements:
-                result[i + 1] = []
                 for element in elements:
                     for each in ELEMENT_TYPE_PATTERNS:
                         patterns = each[0]
@@ -306,6 +309,25 @@ class Template:
             - 2,
         )
 
+    @staticmethod
+    def get_text_field_max_length(element: "pdfrw.PdfDict") -> Union[int, None]:
+        """Returns the max length of the text field if presented or None."""
+
+        return (
+            int(element[TemplateCoreConstants().text_field_max_length_key])
+            if TemplateCoreConstants().text_field_max_length_key in element
+            else None
+        )
+
+    @staticmethod
+    def is_text_field_comb(element: "pdfrw.PdfDict") -> bool:
+        """Returns true if characters in a text field needs to be formatted into combs."""
+
+        try:
+            return "{0:b}".format(int(element["/Ff"]))[::-1][24] == "1"
+        except IndexError:
+            return False
+
     def assign_uuid(self, pdf: bytes) -> bytes:
         """Appends a separator and uuid after each element's annotated name."""
 
@@ -322,10 +344,53 @@ class Template:
             update_dict = {
                 TemplateCoreConstants().annotation_field_key.replace(
                     "/", ""
-                ): "{}{}{}".format(
-                    base_key, MergeConstants().separator, existed_uuid or _uuid
-                )
+                ): f"{base_key}{MergeConstants().separator}{existed_uuid or _uuid}"
             }
             element.update(pdfrw.PdfDict(**update_dict))
 
         return Utils().generate_stream(pdf_file)
+
+    @staticmethod
+    def font_size_for_text_field_with_max_length(
+        element: "pdfrw.PdfDict",
+        max_length: int,
+    ) -> float:
+        """Calculates the font size for a text field with max length."""
+
+        area = abs(
+            float(element[TemplateCoreConstants().annotation_rectangle_key][0])
+            - float(element[TemplateCoreConstants().annotation_rectangle_key][2])
+        ) * abs(
+            float(element[TemplateCoreConstants().annotation_rectangle_key][1])
+            - float(element[TemplateCoreConstants().annotation_rectangle_key][3])
+        )
+
+        return sqrt(area / max_length)
+
+    @staticmethod
+    def get_draw_text_with_max_length_coordinates(
+        element: "pdfrw.PdfDict", element_middleware: "ElementMiddleware"
+    ) -> Tuple[Union[float, int], Union[float, int]]:
+        """Returns coordinates to draw at given a PDF form text field with max length."""
+
+        length = min(len(element_middleware.value), element_middleware.max_length)
+        width = element_middleware.font_size * length * 96 / 72
+        height = element_middleware.font_size * 96 / 72
+        c_half_width = (
+            float(element[TemplateCoreConstants().annotation_rectangle_key][0])
+            + float(element[TemplateCoreConstants().annotation_rectangle_key][2])
+        ) / 2
+        c_half_height = (
+            float(element[TemplateCoreConstants().annotation_rectangle_key][1])
+            + float(element[TemplateCoreConstants().annotation_rectangle_key][3])
+        ) / 2
+
+        return (
+            (c_half_width - width / 2 + c_half_width) / 2
+            - (
+                element_middleware.font_size * 0.5 * 96 / 72
+                if (element_middleware.comb is True and length % 2 == 0)
+                else 0
+            ),
+            (c_half_height - height / 2 + c_half_height) / 2,
+        )
