@@ -312,9 +312,10 @@ class WrapperV2:
         for each in self.elements.values():
             if each.type == ElementType.text:
                 each.font = kwargs.get("global_font", TextConstants().global_font)
-                each.font_size = kwargs.get(
-                    "global_font_size", TextConstants().global_font_size
-                )
+                if each.max_length is None:
+                    each.font_size = kwargs.get(
+                        "global_font_size", TextConstants().global_font_size
+                    )
                 each.font_color = kwargs.get(
                     "global_font_color", TextConstants().global_font_color
                 )
@@ -432,6 +433,17 @@ class WrapperV2:
 
         return self
 
+    def generate_schema(self) -> dict:
+        """Generates a json schema for the PDF form template."""
+
+        result = dict()
+        result["type"] = "object"
+        result["properties"] = {
+            key: value.schema_definition for key, value in self.elements.items()
+        }
+
+        return result
+
     @classmethod
     def register_font(
         cls, font_name: str, ttf_file: Union[bytes, str, BinaryIO]
